%%% Andrea %%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 11/05/06 %%%
%%%           EDDY TRACKING 3D PACKAGE             %%%
%%%                                     vs 3D.1.0  %%%
%%% parameters3d                                   %%%
%%% tracking3d_ini                                 %%%
%%%  |_anim_tracking3d<-ad_extracteur<-census_wlt  %%%
%%%     |_tracking3d                               %%%
%%%     |_eddysection3d                            %%%
%%%     |_trackingvert                             %%%
%%%                                                %%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Reference:
% Doglioli A.M., Blanke B., Speich S., Lapeyre G. (2007),
% Tracking coherent structures in a regional ocean model
% with wavelet analysis: application to Cape Basin Eddies.
% J. Geophys. Res., in press.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% This file is free software ; it is distributed in  %
% the hope that  it  will be useful, but without any %
% warranty. You can redistribute it and/or modify it %
% under the terms of the GNU General Public License  %
% as published by the Free Software Foundation at    %
%       http://www.gnu.org/copyleft/gpl.html.        %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function h=add_speed_vec(fname,gname,tindex,level,skp,npts,...
                         scale,x0,y0,u_unit,units,...
                         fontsize)
hold_state = ishold;
%
% Defaults values
%

if nargin < 1
  error('You must specify a file name')
end
if nargin < 2
  disp('Default time index: 1')
  tindex=1;
end
if nargin < 3
  disp('Default level: -10 m')
  level= -10;
end
if nargin < 4
  disp('Default skip parameter: 1')
  skp=1;
end
if nargin < 5
  disp('Default boundary remove: [0 0 0 0]')
  npts=[0 0 0 0];
end
if nargin < 6
  disp('Default scale: 1')
  scale=1;
end

nc=netcdf(gname);
lat=nc{'lat_rho'}(:);
lon=nc{'lon_rho'}(:);
mask=nc{'mask_rho'}(:);
angle=nc{'angle'}(:);
if isempty(angle)
 disp('Warning: no angle found in history file')
 angle=0*lat;
end
close(nc);
warning off
mask=mask./mask;
warning on

if level==0
  level=-10;
end
if level==0
  u=get_hslice(fname,gname,'ubar',tindex,level,'u');
  v=get_hslice(fname,gname,'vbar',tindex,level,'v');
else
  u=get_hslice(fname,gname,'u',tindex,level,'u');
  v=get_hslice(fname,gname,'v',tindex,level,'v');
end
[u,v,lon,lat,mask]=uv_vec2rho(u,v,lon,lat,angle,mask,skp,npts);
  
if nargin < 8
  u=u*scale;
  v=v*scale;
  h=m_quiver(lon,lat,u,v,0,'w');
else
  h=m_quiver_fix(lon,lat,u,v,scale,x0,y0,u_unit,units,...
                         fontsize,'w');
end
 set(h,'color',[0.5 0.5 0.5],'LineWidth',1);
if ~hold_state, hold off; 
end
return
