%%% Andrea %%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 25/01/06 %%%
%%%           EDDY TRACKING 2D PACKAGE             %%%
%%%                                     vs 2D.1.0  %%%
%%% parameters                                     %%%
%%% tracking_ini                                   %%%
%%%  |_anim_tracking2d<-ad_extracteur<-census_wlt  %%%
%%%     |_tracking2d                               %%%
%%%     |_eddysection                              %%%
%%%                                                %%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% this is G.Lapeyre's code with small modications %%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Reference:
% Doglioli A.M., Blanke B., Speich S., Lapeyre G. (2007),
% Tracking coherent structures in a regional ocean model
% with wavelet analysis: application to Cape Basin Eddies.
% J. Geophys. Res., in press.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% This file is free software ; it is distributed in  %
% the hope that  it  will be useful, but without any %
% warranty. You can redistribute it and/or modify it %
% under the terms of the GNU General Public License  %
% as published by the Free Software Foundation at    %
%       http://www.gnu.org/copyleft/gpl.html.        %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function [final,n_tot]=ad_extracteur2(initial,n_wlt,ad_crit,factor);

% calcule le nombre de tourbillons
% apres filtrage en ondelettes a l'ordre n_wlt


nx=size(initial,1);
ny=size(initial,2);
nt=size(initial,3);

final(1:nx,1:ny,1:nt)=0;

% en pratique, il faut modifier n_dep
% pour avoir le meilleur resultat
n_dep=20;n_dep2=2*n_dep+1;

for it=1:nt

  % filtrage par ondelettes
  [zctot,zc,zr]=census_wlt2(initial(:,:,it),n_wlt,factor);
  ini=zctot(:,:,n_wlt);

  temp2=initial(:,:,it);
  temp2(find(ini==0))=0;
  temp=ini;
  
  data1(1:(nx+3*n_dep),1:ny)=0;
  data1(1+n_dep+(1:nx),1:ny)=temp.^2;

  % le filtre va permettre d'enlever les autres tourbillons
  filtre(1:nx,1:ny)=1;
  filtre_t(1:nx,1:ny,1:n_dep2)=1;

  tempx(1:nx,1:ny,1:n_dep2)=0;

  for ix=1:n_dep2
    tempx(:,:,ix)=data1(ix+(1:nx),1:ny);
  end
  
  % premiere etape, en avant
  for ix=(1+n_dep):n_dep2
    filtre(find(tempx(:,:,ix)==0))=0;
    if(ix<n_dep2)
      % je filtre quand je trouve une inversion
      toto=find(and(tempx(:,:,ix-1)>tempx(:,:,ix),...
	  tempx(:,:,ix+1)>tempx(:,:,ix)));
      filtre(toto)=0;
    end
    filtre_t(:,:,ix)=filtre;
  end
  
  filtre(1:nx,1:ny)=1;
  % en arriere
  for ix=(1+n_dep):-1:1

    if(ix>1)
      % je filtre quand je trouve une inversion
      toto=find(and(tempx(:,:,ix-1)>tempx(:,:,ix), ...
	  tempx(:,:,ix+1)>tempx(:,:,ix)));
      filtre(toto)=0;
    end
    filtre(find(tempx(:,:,ix)==0))=0;
    filtre_t(:,:,ix)=filtre;
  end
  
  
  temp2=max(filtre_t.*tempx,[],3);
  temp2(find(temp==0))=0;

  
  
% on fait la meme chose dans l'autre direction
  tempx(1:nx,1:ny,1:n_dep2)=0;  
    
  data1(1:(nx+3*n_dep),1:ny)=0;
  data1(1+n_dep+(1:nx),1:ny)=temp2';
  
  filtre(1:nx,1:ny)=1;
  filtre_t(1:nx,1:ny,1:n_dep2)=1;

  for ix=1:n_dep2
    tempx(:,:,ix)=data1(ix+(1:nx),1:ny);
  end
  
  % en avant:
  for ix=(1+n_dep):n_dep2
    filtre(find(tempx(:,:,ix)==0))=0;
    if(ix<n_dep2)
      % je filtre quand je trouve une inversion
      toto=find(and(tempx(:,:,ix-1)>tempx(:,:,ix)...
	  ,tempx(:,:,ix+1)>tempx(:,:,ix)));
      filtre(toto)=0;
    end
    filtre_t(:,:,ix)=filtre;
  end
  
  filtre(1:nx,1:ny)=1;
  % en arriere:
  for ix=(1+n_dep):-1:1
    filtre(find(tempx(:,:,ix)==0))=0;
    if(ix>1)
      % je filtre quand je trouve une inversion
      toto=find(and(tempx(:,:,ix-1)>tempx(:,:,ix), ...
	  tempx(:,:,ix+1)>tempx(:,:,ix)));
      filtre(toto)=0;
    end
    filtre_t(:,:,ix)=filtre;
  end
    
  temp3=max(filtre_t.*tempx,[],3)';
  temp3(find(temp==0))=0;

  % on corrige les tourbillons de bord
  for ix=1:nx
    if(and(temp3(ix,1)>0,temp3(ix,nx)>0))
      xx=max(temp3(ix,1),temp3(ix,nx));
      yy=min(temp3(ix,1),temp3(ix,nx));
      temp3(find(temp3==yy))=xx;
    end
  end
  for ix=1:nx
    if(and(temp3(1,ix)>0,temp3(nx,ix)>0))
      xx=max(temp3(1,ix),temp3(nx,ix));
      yy=min(temp3(1,ix),temp3(nx,ix));
      temp3(find(temp3==yy))=xx;
    end
  end
      

  kata(1:nx,1:ny)=0;
  
  % maintenant on calcule le nombre de tourbillons
  n_tourb=0;
  tot_per=size(find(temp3>0),1)/nx/ny;
  while(tot_per>0.001)
    xx=max(max(temp3));
    uu=find(temp3==xx);
%    uu=find(abs(temp3-xx)<xx*0.1);
    toto=size(uu,1);

    % on ne considere que les  tourbillons 
    %     avec plus de 100 points de grille
    %       a 512^2 
    if(toto>ad_crit)
      n_tourb=n_tourb+1;
      kata(uu)=n_tourb;
    end
    temp3(uu)=0;
    tot_per=size(find(temp3>0),1)/nx/ny;
  end
  n_tot(it)=n_tourb;
  final(:,:,it)=kata; 
  
  
end
