%%%% Andrea %%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 13/07/07 %%%%%%%%
%%%%           EDDY TRACKING 3D PACKAGE                  %%%
%%%%                                     vs 3D.1.1       %%%
%%%% parameters3d                                        %%%
%%%% tracking3d_ini                                      %%%
%%%%  |_anim_tracking3d<-ad_extracteur<-census_wlt       %%%
%%%%     |_tracking3d                                    %%%
%%%%     |_eddysection3d                                 %%%
%%%%     |_trackingvert                                  %%%
%%%%                                                     %%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Reference:                                              %
%% Doglioli A.M., Blanke B., Speich S., Lapeyre G. (2007), %
%% Tracking coherent structures in a regional ocean model  %
%% with wavelet analysis: application to Cape Basin Eddies.%
%% J.Geophys.Res., 112, C05043, doi:10.1029/2006JC003952.  %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% This  file  is  free software ;  it  is distributed  in %
%% the hope that  it  will  be  useful,  but  without  any %
%% warranty.  You  can  redistribute  it and/or modify  it %
%% under  the  terms  of  the  GNU  General Public License %
%% as  published  by  the   Free  Software  Foundation  at %
%%       http://www.gnu.org/copyleft/gpl.html.             %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

clear;close all;
%
%--- source files
simu='Agu10'; %%% conventional name
gridfile='roms_grd.nc';
datafile='roms_avg';
%simu='Res10'; %%% conventional name
%gridfile='/local/tmp/1/doglioli/Res10/roms_grd.nc';
%datafile='/local/tmp/1/doglioli/Res10/Run/roms_avg';
%simu='GASC_POP25'; %%% conventional name
%gridfile='/net/vela/local/tmp/2/doglioli/GAS_POP25/roms_grd.nc';
%datafile='/net/vela/local/tmp/2/doglioli/GAS_POP25/roms_avg';
%gridfile='/net/vela/local/tmp/2/blanke/reduc_roms_grd.nc';
%datafile='/net/vela/local/tmp/2/blanke/reduc_roms_avg';
%
%--- time parameters
cycledir='fwd'; %%% temporal direction of analisys -> bkw or fwd
fr0=0;          %%% number of first frame !!! fr-1
Ymin=7;         %%% first year
Mmin=3;         %%% first month
%Dmin=30;       %%% only for GASC_POP25 output file
itmin=1;        %%% first interval
Ymax=7;         %%% last year      
Mmax=3;         %%% last month
%Dmax=30;       %%% only for GASC_POP25 output file
itmax=15;       %%% last interval
vlevel=-200;    %%% shallowest vertical level %%% [m]
%
%--- 3D parameters
Zmin=-1001;     %%% deepest vertical level %%% [m] DA TOGLIERE
depthincr=-200; %%% distance between two successive horizontal slices %%% [m]
%
%--- analysis setup
extraction='old'; %%% kind of wavelet exraction %%% [new/old] WARNING new is accurate but time consuming
factor=0.25;      %%% of number of spectral coefs
varname='vort';   %%% wavelets analysis variable -> vorp,vori,vort(BEST),salt,temp,zeta NB:vori only forward 
coef=10^5;        %%% var rescaling       
interval=[-2.5:0.5:2.5];%%% contour plot
delta=2^8;        %%% dim of area of research %%% [grid meshes] 
jmin=60;          %%% grid coordinates of bottom left corner of analysis area
imin=50;          %%%  "       "       "    "     "     "    "     "      "
% 
centerselec='vort';%%% center definition: max(abs(vorticity)) or min(speed) %%% [vort/spee]
ad_crit=30;        %%% min surface of an eddy %%% [grid meshes] 
cutoff=0.;         %%% var cutoff %%% [*coef]
%
%--- plot
varname2='vort';   %%% contour plot variable %%% [vorp,vori,vort,salt,temp,zeta]
coef2=1;           %%% var2 rescaling 
interval2=[35.3:0.02:36.3];%%% contour levels %%% [units of var2]
contouring='y';    %%% contour around eddy %%% [y/n]
cross='n';         %%% plot a cross as reference of vertical sections %%% [y/n]
sect=1;            %%% vertical section extention %%% [lat& lon degree]
numbering='n';     %%% put the eddy number in eddy meshes %%% [y/n]  |
freqnumbering=3;   %%% every freqnumbering meshes                  <-
%
lonrange1=[-6 25];    %%% lon range of first figure
latrange1=[-46.5 -25];%%% lat   "   "    "     "
lonrange2=[-6 25];    %%% lon range of other figures
latrange2=[-46.5 -25];%%% lat   "   "    "     "
%
%--- output file names
moviename='animation';
sectionsname='sections';
%
%%%%%%%%% DON'T TOUCH BELOW %%%%%%%%%%%%%%%%%%
jmax=jmin+delta-1;
imax=imin+delta-1;
%
nc=netcdf(gridfile);
topo=nc{'h'}(:);
topo=-topo;
pm=nc{'pm'}(:);
pn=nc{'pn'}(:);
angle=nc{'angle'}(:);
close(nc)
%
anomalycalc=0;
periodicity=0;
filter_vort=1;
fierl='si';
%--- for Ariane
lmt=99999;         %ariane initial positions in vertical tracking
timedir='BW';    % "
%
navgdays=2; %[days] print frequency
skipanim=1;
rempts=[0 0 0 0];
%
scrsz = get(0,'ScreenSize');
figure(1);set(1,'Visible','on','Position',[scrsz(3)/3 scrsz(4) scrsz(3)/1.5 scrsz(4)/1.5])
figure(1);hold on;
m_proj('mercator','lon',lonrange1,'lat',latrange1) %all Agu10
%m_grid('color',[0 0 0]);
m_grid('box','fancy');
%--- coastline
%m_gshhs_c('patch',[.5 .6 .5]);
%m_gshhs_h('patch',[.5 .6 .5]);
%ad_add_towns('town.dat',6,min(min(lon)),19,min(min(lat)),max(max(lat)))
pause(1)

save parameters3d.mat
%%%%%%%%%%%%%%%%%%%%%%%%%%%