%%%% Andrea %%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 13/07/07 %%%%%%%%
%%%%           EDDY TRACKING 3D PACKAGE                  %%%
%%%%                                     vs 3D.1.1       %%%
%%%% parameters3d                                        %%%
%%%% tracking3d_ini                                      %%%
%%%%  |_anim_tracking3d<-ad_extracteur<-census_wlt       %%%
%%%%     |_tracking3d                                    %%%
%%%%     |_eddysection3d                                 %%%
%%%%     |_trackingvert                                  %%%
%%%%                                                     %%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Reference:                                              %
%% Doglioli A.M., Blanke B., Speich S., Lapeyre G. (2007), %
%% Tracking coherent structures in a regional ocean model  %
%% with wavelet analysis: application to Cape Basin Eddies.%
%% J.Geophys.Res., 112, C05043, doi:10.1029/2006JC003952.  %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% This  file  is  free software ;  it  is distributed  in %
%% the hope that  it  will  be  useful,  but  without  any %
%% warranty.  You  can  redistribute  it and/or modify  it %
%% under  the  terms  of  the  GNU  General Public License %
%% as  published  by  the   Free  Software  Foundation  at %
%%       http://www.gnu.org/copyleft/gpl.html.             %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Press Enter to Start
help tracking3d_ini
pause
disp('  Running...');
%
clear;close all;

parameters3d

if cycledir=='fwd';Y=Ymin; M=Mmin; tindex=itmin; end;
if cycledir=='bkw';Y=Ymax; M=Mmax; tindex=itmax; end;
%if cycledir=='fwd';Y=Ymin; M=Mmin; D=Dmin; tindex=itmin; end;
%if cycledir=='bkw';Y=Ymax; M=Mmax; D=Dmax; tindex=itmax; end;

hisfile=[datafile,'_Y',num2str(Y),'M',num2str(M),'.nc'];
%hisfile=[datafile,'_Y',num2str(Y),'M',num2str(M),'D',num2str(D),'.nc'];

%--- getting field for analysis
if varname == 'zeta'
 [lat,lon,mask,var]=get_var(hisfile,gridfile,varname,tindex,0,coef,rempts);
end%if
if varname == 'temp'
 [lat,lon,mask,var]=get_var(hisfile,gridfile,varname,tindex,vlevel,coef,rempts);
end%if
if varname == 'salt'
 [lat,lon,mask,var]=get_var(hisfile,gridfile,varname,tindex,vlevel,coef,rempts);
end%if
if varname == 'vort'
 [lat,lon,mask,var]=get_vort(hisfile,gridfile,tindex,vlevel,coef);
end%if
if varname=='vort';
 [lat,lon,mask,var]=get_vort(hisfile,gridfile,tindex,vlevel,coef);
end
if varname=='vorp';
 %fname='/net/centaure/local/tmp/6/speich/CCauldronMdue/Res10/Run/roms_avg_Y1M1.nc';
 fname='/local/tmp/1/doglioli/Res10/Run/roms_avg_Y1M1.nc';
 %__metodo A
 %[lat,lon,mask,pv]=get_pv(hisfile,gridfile,tindex,vlevel,1);
 %[lat,lon,mask,ppv]=get_ppv(fname,gridfile,1,vlevel,1);
 %var=pv-ppv(81,23);%anomaly rispetto lon8 lat -37
 %var=var*coef;
 %__metodo B
 [lat,lon,mask,var]=get_dpv(hisfile,gridfile,tindex,vlevel,coef,fname,71,23);
end
%--------------------------------------

%--- getting velocity
if centerselec=='spee';
u=get_hslice(hisfile,gridfile,'u',tindex,vlevel,'u');
v=get_hslice(hisfile,gridfile,'v',tindex,vlevel,'v');
u=u2rho_2d(u);
v=v2rho_2d(v);
var2=sqrt(u.*u+v.*v);
clear u v
end

%--- area of eddy research: it MUST be 2^n x 2^n
[jsize,isize]=size(var);
if imax>=isize | jmax>=jsize;
 disp(' imax>=isize | jmax>=jsize');
 disp(' imax jmax isize jsize')
 disp([' ',num2str([imax  jmax isize jsize])])
 break
end
for j=jmin:jmax;
 for i=imin:imax;
   myvar(j-jmin+1,i-imin+1)=var(j,i);
   if centerselec=='spee';myvar2(j-jmin+1,i-imin+1)=var2(j,i); end
 end
end

%--- no periodicity
myvar(1,:)=0; myvar(:,1)=0; 

%--- filter cut off
indici=find(abs(myvar)<=cutoff); myvar(indici)=0; 

%--- zero on land
indici1=find(isnan(myvar)==1);
myvar(indici1)=0;

%--- G.Lapeyre's function
if extraction=='old';
 [final,ntot]=ad_extracteur2(myvar,3,ad_crit,factor);
end
if extraction=='new';
 % on interpolera sur une grille de resolution nfac*delta
 nfac=2;
 % si la distance entre deux tourbillons est plus petite
 % que rdist, alors on considere que ce sont les memes tourbillons
 rdist=3*nfac;
 % taille maximale d'un tourbillon
 nsize=20*nfac^2;
 % si on a un filament de taille 2*nsep, on le coupera
 nsep=2+nfac;
 [final,ntot]=nouv_extract(myvar,nfac,rdist,nsize,nsep,factor);
end

%--- plotting
%---- contour
[C,hcontf]=m_contourf(lon(jmin:jmax,imin:imax),lat(jmin:jmax,imin:imax),myvar);
set(hcontf,'EdgeColor','none','FaceColor','flat');

h=colorbar;
h2=get(h,'ylabel');
set(h2,'string',['{\bf ',varname,' coef=',num2str(coef,'%6.2e'),'}']);

%--- velocity vectors
ad_add_speed_vec(hisfile,gridfile,tindex,vlevel,4,[3 3 3 0],0.9);

%--- bathymetry
m_contour(lon,lat,topo,[-1000 -2000 -3000 -4000],'b');

%--- eddies contour, labelling and centering
%if contouring=='y'; 
 [C,h]=m_contour(lon(jmin:jmax,imin:imax),lat(jmin:jmax,imin:imax),final,[0 1]);
 set(h,'LineWidth',1,'EdgeColor','k','FaceColor','none');
%end
if numbering=='y';
 for j=1:freqnumbering:delta
  for i=1:freqnumbering:delta
   if final(j,i)~=0
    m_text(lon(j+jmin-1,i+imin-1),lat(j+jmin-1,i+imin-1),['{ ', num2str(final(j,i)) ,'}'],'Color',[0  0 0],'BackgroundColor',[0 0 0 ],'FontSize',3);
   end
  end
 end
end%if numbering=='y'

%fid=fopen(['initial_',varname,'_Y',num2str(Y),'M',num2str(M),'it',num2str(tindex),'.txt'],'w');
%fprintf(fid,[simu,'   Y=',num2str(Y,'%2.0f'),'   M=',num2str(M,'%2.0f'),'   it=',num2str(tindex,'%2.0f'),'    vlevel=',num2str(vlevel),'\n']);
%fprintf(fid,['ad-crit=',num2str(ad_crit),'  cutoff=',num2str(cutoff),'  ntot=',num2str(ntot),'  centerselec=',centerselec,'\n']) ;
%fprintf(fid,'    neddy   jcenter   icenter  eddysurf\n');
%fclose(fid);
for neddy=1:ntot
 %neddy
 [jeddy,ieddy]=find(final==neddy);
 eddy=find(final==neddy);
 if isempty(eddy)==0
  eddysurf=size(eddy);
  if centerselec=='vort';
   center=max(max(abs(myvar(eddy))));
   [jcenter,icenter]=find( abs(myvar) == center & final==neddy);
  end
  if centerselec=='spee';
   center=min(min(myvar2(eddy)));
   [jcenter,icenter]=find( myvar2 == center);
  end
  lonc=lon(jcenter+jmin-1,icenter+imin-1);
  latc=lat(jcenter+jmin-1,icenter+imin-1);
  if lonc>lonrange1(1) & lonc<lonrange1(2) & latc>latrange1(1) & latc<latrange1(2)  
   m_text(lonc,latc,['.',num2str(neddy),'(',num2str(jcenter),',',num2str(icenter),')'],'Color',[0  0 0],'FontWeight','bold','FontSize',5);
  end
  fid=fopen(['initial_',varname,'_Y',num2str(Y),'M',num2str(M),'it',num2str(tindex),'.txt'],'a');
%fid=fopen(['initial_',varname,'_Y',num2str(Y),'M',num2str(M),'D',num2str(D,'%2.0f'),'it',num2str(tindex),'.txt'],'a');
  fprintf(fid,'%9.0f %9.0f %9.0f %9.0f\n',neddy,jcenter,icenter,eddysurf(1));
 end%if isempty(eddy)==0
end%for neddy=1:ntot
fclose(fid);

%--- contour of area of eddy research
m_line([lon(jmin,imin) lon(jmax,imin)],[lat(jmin,imin) lat(jmax,imin)],'color','r');
m_line([lon(jmax,imin) lon(jmax,imax)],[lat(jmax,imin) lat(jmax,imax)],'color','r');
m_line([lon(jmax,imax) lon(jmin,imax)],[lat(jmax,imax) lat(jmin,imax)],'color','r');
m_line([lon(jmin,imax) lon(jmin,imin)],[lat(jmin,imax) lat(jmin,imin)],'color','r');

%--- coastline
%m_gshhs_c('patch',[.5 .6 .5]);
m_gshhs_h('patch',[.5 .6 .5]);
%ad_add_towns('town.dat',6,min(min(lon)),19,min(min(lat)),max(max(lat)))

%--- legenda
title([simu,'   Y=',num2str(Y,'%2.0f'),'   M=',num2str(M,'%2.0f'),'   it=',num2str(tindex,'%2.0f'),'    vlevel=',num2str(vlevel)],'FontWeight','bold','Interpreter','none')
%title([simu,'   Y=',num2str(Y,'%2.0f'),'   M=',num2str(M,'%2.0f'),'   D=',num2str(D,'%2.0f'),'   it=',num2str(tindex,'%2.0f'),'    vlevel=',num2str(vlevel)],'FontWeight','bold','Interpreter','none')
xlabel(['{\bf ad-crit=',num2str(ad_crit),'  cutoff=',num2str(cutoff),'  ntot=',num2str(ntot),'  centerselec=',centerselec,'} '])
%add_arrow(min(min(lon)),max(max(lon)),min(min(lat)),max(max(lat)),1,scale,1,1)
%
hold off;

%--- EPS file
orient portrait;
saveas(1,['./initial_',varname,'_Y',num2str(Y),'M',num2str(M),'it',num2str(tindex),'.eps'],'epsc2');
%print('-depsc',['./initial_',varname,'_Y',num2str(Y),'M',num2str(M),'D',num2str(D),'it',num2str(tindex),'.eps'],'-loose');       
%close(1)

%---- eddy selection by mouse
disp(' ')
disp('Select eddy by mouse! left->read; rigth->start');
pb=1;
while pb == 1
 [x1,y1,button] = ginput(1);
 [lon1,lat1]=m_xy2ll(x1,y1);

 [jlat,trash]=findnearest(lat1,lat);
 jcentermouse=jlat(1)-jmin+1;
 [trash,ilon]=findnearest(lon1,lon);
 icentermouse=ilon(1)-imin+1;
 disp(' ')
 disp(sprintf('lat     %5.2f lon     %5.2f',lat1,lon1));
 disp(sprintf('jcenter %5.0f icenter %5.0f',jcentermouse,icentermouse));

 eddysign=sign(myvar(jcentermouse,icentermouse));
 disp(sprintf('eddysign %3.0f',eddysign));

 if button==3
  jcenter=jcentermouse;
  icenter=icentermouse;
  ycenter=jcentermouse;
  xcenter=icentermouse;
  pb=0;
 end%if
end%while

disp(' ')
disp('Tracking 3D started!');

if fierl=='si';
nc=netcdf(hisfile);
ntime=length(nc('time'));
mintopo=min(min(topo));
dim1=abs(round((vlevel-mintopo)/depthincr));
dim2=abs(itmax+ntime*Mmax+ntime*12*Ymax-itmin+ntime*Mmin+ntime*12*Ymin);
veltangmemo(1:dim1,1:dim2)=NaN;
vecentermemo(1:dim2)=NaN;
end

%figure(6);figure(7);figure(8);figure(9);
pause(2)
close all
anim_tracking3d
%%%%%%%%%%%%%%%%%%%%%%%%%